@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 120.system.php 1492 2010-11-27 10:37:44Z Dessa $
+ * @version    $Id: 120.system.php 1543 2010-12-07 11:08:41Z d00p $
  */
 
 return array(
@@ -29,6 +29,7 @@ return array(
 					'type' => 'string',
 					'default' => '/var/customers/webs/',
 					'save_method' => 'storeSettingField',
+					'plausibility_check_method' => 'checkPathConflicts'
 					),
 				'system_ipaddress' => array(
 					'label' => $lng['serversettings']['ipaddress'],
@@ -58,6 +59,22 @@ return array(
 					'default' => '',
 					'save_method' => 'storeSettingHostname',
 					),
+				'system_froxlordirectlyviahostname' => array(
+					'label' => $lng['serversettings']['froxlordirectlyviahostname'],
+					'settinggroup' => 'system',
+					'varname' => 'froxlordirectlyviahostname',
+					'type' => 'bool',
+					'default' => false,
+					'save_method' => 'storeSettingField',
+					),
+				'system_stdsubdomain' => array(
+					'label' => $lng['serversettings']['stdsubdomainhost'],
+					'settinggroup' => 'system',
+					'varname' => 'stdsubdomain',
+					'type' => 'string',
+					'default' => '',
+					'save_method' => 'storeSettingHostname',
+					),
 				'system_mysql_access_host' => array(
 					'label' => $lng['serversettings']['mysql_access_host'],
 					'settinggroup' => 'system',
