@@ -12,13 +12,14 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 135.fcgid.php 1506 2010-11-29 07:37:00Z d00p $
+ * @version    $Id: 135.fcgid.php 1534 2010-12-03 10:41:12Z d00p $
  */
 
 return array(
 	'groups' => array(
 		'fcgid' => array(
 			'title' => $lng['admin']['fcgid_settings'],
+			'websrv_avail' => array('apache2', 'lighttpd'),
 			'fields' => array(
 				'system_mod_fcgid_enabled' => array(
 					'label' => $lng['serversettings']['mod_fcgid'],
@@ -27,6 +28,7 @@ return array(
 					'type' => 'bool',
 					'default' => false,
 					'save_method' => 'storeSettingField',
+					'plausibility_check_method' => 'checkFcgidPhpFpm',
 					'overview_option' => true
 					),					
 				'system_mod_fcgid_configdir' => array(
@@ -67,6 +69,7 @@ return array(
 					'option_options' => array(0 => 'ScriptAlias', 1=> 'FCGIWrapper'),
 					'default' => 1,
 					'save_method' => 'storeSettingField',
+					'websrv_avail' => array('apache2')
 					),
 				'system_mod_fcgid_starter' => array(
 					'label' => $lng['serversettings']['mod_fcgid']['starter'],
@@ -101,6 +104,7 @@ return array(
 					'type' => 'bool',
 					'default' => false,
 					'save_method' => 'storeSettingField',
+					'websrv_avail' => array('apache2')
 					),
 				'system_mod_fcgid_httpuser' => array(
 					'label' => $lng['admin']['mod_fcgid_user'],
@@ -109,6 +113,7 @@ return array(
 					'type' => 'string',
 					'default' => 'froxlorlocal',
 					'save_method' => 'storeSettingField',
+					'websrv_avail' => array('apache2')
 					),
 				'system_mod_fcgid_httpgroup' => array(
 					'label' => $lng['admin']['mod_fcgid_group'],
@@ -117,6 +122,7 @@ return array(
 					'type' => 'string',
 					'default' => 'froxlorlocal',
 					'save_method' => 'storeSettingField',
+					'websrv_avail' => array('apache2')
 					),
 				'system_mod_fcgid_defaultini_ownvhost' => array(
 					'label' => $lng['serversettings']['mod_fcgid']['defaultini_ownvhost'],
@@ -127,6 +133,7 @@ return array(
 					'option_mode' => 'one',
 					'option_options_method' => 'getPhpConfigs',
 					'save_method' => 'storeSettingField',
+					'websrv_avail' => array('apache2')
 					),
 				)
 			)
