@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 137.perl.php 1492 2010-11-27 10:37:44Z Dessa $
+ * @version    $Id: 137.perl.php 1521 2010-12-02 08:18:46Z d00p $
  */
 
 return array(
@@ -27,6 +27,7 @@ return array(
 					'type' => 'string',
 					'default' => '/usr/bin/perl',
 					'save_method' => 'storeSettingField',
+					'websrv_avail' => array('lighttpd')
 					),	
 				'system_perl_suexecworkaround' => array(
 					'label' => $lng['serversettings']['perl']['suexecworkaround'],
@@ -35,6 +36,7 @@ return array(
 					'type' => 'bool',
 					'default' => false,
 					'save_method' => 'storeSettingField',
+					'websrv_avail' => array('apache2')
 					),
 				'system_perl_suexeccgipath' => array(
 					'label' => $lng['serversettings']['perl']['suexeccgipath'],
@@ -43,6 +45,7 @@ return array(
 					'type' => 'string',
 					'default' => '/var/www/cgi-bin/',
 					'save_method' => 'storeSettingField',
+					'websrv_avail' => array('apache2')
 					),
 				'perl_server' => array(
 					'label' => $lng['serversettings']['perl_server'],
@@ -51,6 +54,7 @@ return array(
 					'type' => 'string',
 					'default' => 'unix:/var/run/nginx/cgiwrap-dispatch.sock',
 					'save_method' => 'storeSettingField',
+					'websrv_avail' => array('nginx')
 					),
 				),
 			),
