@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Panel
- * @version    $Id: index.php 1342 2010-10-15 11:48:05Z d00p $
+ * @version    $Id: index.php 1536 2010-12-05 17:15:24Z d00p $
  */
 
 define('AREA', 'login');
@@ -336,7 +336,7 @@ if($action == 'forgotpwd')
 					try {
 						$mail->Subject = $mail_subject;
 						$mail->AltBody = $mail_body;
-						$mail->MsgHTML(str_replace("\\n", "<br />", $mail_body));
+						$mail->MsgHTML(str_replace("\n", "<br />", $mail_body));
 						$mail->AddAddress($user['email'], $user['firstname'] . ' ' . $user['name']);
 						$mail->Send();
 					} catch(phpmailerException $e) {
