@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Install
- * @version    $Id: install.php 1484 2010-11-26 12:30:54Z Dessa $
+ * @version    $Id: install.php 1556 2010-12-25 22:43:42Z scarya $
  */
 
 /**
@@ -212,6 +212,20 @@ function requirement_checks()
 	{
 		status_message('green', 'OK');
 	}
+	
+	status_message('begin', $lng['install']['phpxml']);
+	
+	if(!extension_loaded('xml'))
+	{
+		status_message('red', $lng['install']['notinstalled']);
+		$_die = true;
+	}
+	else
+	{
+		status_message('green', 'OK');
+	}
+
+
 
 	status_message('begin', $lng['install']['phpfilter']);
 
