@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: gentoo.inc.php 1485 2010-11-26 12:32:47Z Dessa $
+ * @version    $Id: gentoo.inc.php 1530 2010-12-02 12:51:14Z d00p $
  */
 
 return Array(
@@ -39,6 +39,12 @@ return Array(
 							'mkdir -p ' . $settings['system']['mod_fcgid_tmpdir'],
 							'chmod 1777 ' . $settings['system']['mod_fcgid_tmpdir']
 						),
+						'files' => ((int)$settings['phpfpm']['enabled'] == 1) ?
+							Array(
+								'etc_apache2_modules.d_70_fastcgi.conf' => '/etc/apache2/modules.d/70_fastcgi.conf'
+							)
+							:
+							null,
 						'restart' => Array(
 							'rc-update add apache2 default',
 							'/etc/init.d/apache2 restart'
