@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: lenny.inc.php 1484 2010-11-26 12:30:54Z Dessa $
+ * @version    $Id: lenny.inc.php 1530 2010-12-02 12:51:14Z d00p $
  */
 
 return Array(
@@ -34,6 +34,12 @@ return Array(
 							'chmod 1777 ' . $settings['system']['mod_fcgid_tmpdir'],
 							'a2dismod userdir'
 						),
+						'files' => ((int)$settings['phpfpm']['enabled'] == 1) ?
+							Array(
+								'etc_apache2_mods-enabled_fastcgi.conf' => '/etc/apache2/mods-enabled/fastcgi.conf'
+							)
+							:
+							null,
 						'restart' => Array(
 							'/etc/init.d/apache2 restart'
 						),
