@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.validatePassword.php 632 2010-03-17 07:51:16Z d00p $
+ * @version    $Id: function.validatePassword.php 1189 2010-07-19 08:06:18Z d00p $
  */
 
 /**
@@ -39,5 +39,14 @@ function validatePassword($password = null)
 		);
 	}
 	
+	if ($settings['panel']['password_regex'] != '') {
+		$password = validate(
+			$password, 
+			$settings['panel']['password_regex'],
+			$settings['panel']['password_regex'], 
+			'notrequiredpasswordcomplexity'
+		);
+	}
+	
 	return $password;
 }
