@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    System
- * @version    $Id: init.php 1281 2010-09-17 10:33:58Z d00p $
+ * @version    $Id: init.php 1450 2010-11-09 09:16:08Z d00p $
  */
 
 // prevent Froxlor pages from being cached
@@ -183,7 +183,12 @@ if(!isset($settings['admin']['froxlor_graphic'])
  */
 
 $remote_addr = $_SERVER['REMOTE_ADDR'];
-$http_user_agent = $_SERVER['HTTP_USER_AGENT'];
+
+if (empty($_SERVER['HTTP_USER_AGENT'])) {
+	$http_user_agent = 'unknown';
+} else {
+	$http_user_agent = $_SERVER['HTTP_USER_AGENT'];
+}
 unset($userinfo);
 unset($userid);
 unset($customerid);
