@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Navigation
- * @version    $Id: 00.froxlor.main.php 692 2010-03-26 08:42:13Z d00p $
+ * @version    $Id: 00.froxlor.main.php 1538 2010-12-06 07:38:55Z d00p $
  */
 
 return array (
@@ -218,7 +218,14 @@ return array (
 				array (
 					'url' => 'admin_phpsettings.php?page=overview',
 					'label' => $lng['menue']['phpsettings']['maintitle'],
-					'show_element' => ( getSetting('system', 'mod_fcgid') == true ),
+					'show_element' => ( 
+						getSetting('system', 'mod_fcgid') == true 
+						/* 
+						 * @TODO activate if phpfpm knows custom php.ini files
+						 * 
+						 * || getSetting('phpfpm', 'enabled') == true
+						 */
+						),
 				),
 			),
 		),
