@@ -16,7 +16,7 @@
  * @author     Froxlor Team <team@froxlor.org>
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: portugues.lng.php 759 2010-04-09 19:24:17Z EleRas $
+ * @version    $Id: portugues.lng.php 1338 2010-10-15 06:50:25Z d00p $
  */
 
 /**
@@ -772,10 +772,6 @@ $lng['pwdreminder']['body'] = 'Oi %s,\n\nsua senha do Froxlor foi resetada!\nA n
 $lng['pwdreminder']['success'] = 'Redefini&ccedil;&atilde;o de senha com sucesso. <br /> Voc&ecirc; agora deve receber um e-mail com sua nova senha.';
 $lng['serversettings']['allow_password_reset']['title'] = 'Aceita reset de senha por clientes';
 $lng['pwdreminder']['notallowed'] = 'Reset de senhas est&aacute; desativado';
-$lng['serversettings']['awstats_path']['title'] = 'Caminho para pasta awstats cgi-bin';
-$lng['serversettings']['awstats_path']['description'] = 'Exemplo: /usr/share/webapps/awstats/6.1/webroot/cgi-bin/';
-$lng['serversettings']['awstats_updateall_command']['title'] = 'Caminho para &quot;awstats_updateall.pl&quot;';
-$lng['serversettings']['awstats_updateall_command']['description'] = 'Exemplo: /usr/bin/awstats_updateall.pl';
 $lng['customer']['title'] = 'T&iacute;tulo';
 $lng['customer']['country'] = 'Pa&iacute;s';
 $lng['panel']['dateformat'] = 'AAAA-MM-DD';
