@@ -14,10 +14,10 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_apsupdater.php 115 2010-01-25 13:19:45Z EleRas $
+ * @version    $Id: cron_apsupdater.php 425 2010-02-22 12:24:45Z d00p $
  */
 
-$Aps = new ApsUpdater($db);
+$Aps = new ApsUpdater($db, $cronlog);
 $Aps->UpdateHandler();
 
 ?>
