@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.10.apache.php 1508 2010-11-29 07:44:24Z d00p $
+ * @version    $Id: cron_tasks.inc.http.10.apache.php 1552 2010-12-21 10:55:08Z d00p $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -57,6 +57,12 @@ class apache
 
 	public function reload()
 	{
+		if((int)$this->settings['phpfpm']['enabled'] == 1)
+		{
+			fwrite($this->debugHandler, '   apache::reload: reloading php-fpm' . "\n");
+			$this->logger->logAction(CRON_ACTION, LOG_INFO, 'reloading php-fpm');
+			safe_exec(escapeshellcmd($this->settings['phpfpm']['reload']));
+		}
 		fwrite($this->debugHandler, '   apache::reload: reloading apache' . "\n");
 		$this->logger->logAction(CRON_ACTION, LOG_INFO, 'reloading apache');
 		safe_exec(escapeshellcmd($this->settings['system']['apachereload_command']));
@@ -76,9 +82,10 @@ class apache
 		}
 		$vhosts_filename = makeCorrectFile($vhosts_folder . '/05_froxlor_dirfix_nofcgid.conf');
 
-		if($this->settings['system']['mod_fcgid'] == '1')
-		{
-			// if we use fcgid we don't need this file
+		if($this->settings['system']['mod_fcgid'] == '1'
+			|| $this->settings['phpfpm']['enabled'] == '1'
+		) {
+			// if we use fcgid or php-fpm we don't need this file
 			if(file_exists($vhosts_filename))
 			{
 				fwrite($this->debugHandler, '  apache::_createStandardDirectoryEntry: unlinking ' . basename($vhosts_filename) . "\n");
@@ -220,7 +227,7 @@ class apache
 				if($this->settings['system']['mod_fcgid_ownvhost'] == '1')
 				{
 					
-					$configdir = makeCorrectDir($this->settings['system']['mod_fcgid_configdir'] . '/froxlor.panel/');
+					$configdir = makeCorrectDir($this->settings['system']['mod_fcgid_configdir'] . '/froxlor.panel/' . $this->settings['system']['hostname']);
 					if((int)$this->settings['system']['mod_fcgid_wrapper'] == 0)
 					{
 						$this->virtualhosts_data[$vhosts_filename].= '  SuexecUserGroup "' . $this->settings['system']['mod_fcgid_httpuser'] . '" "' . $this->settings['system']['mod_fcgid_httpgroup'] . '"' . "\n";
@@ -239,6 +246,35 @@ class apache
 						$this->virtualhosts_data[$vhosts_filename].= '  </Directory>' . "\n";
 					}
 				}
+				// create php-fpm <Directory>-Part (config is created in apache_fcgid)
+				elseif($this->settings['phpfpm']['enabled'] == '1')
+				{
+					$domain = array(
+						'id' => 'none',
+						'domain' => $this->settings['system']['hostname'],
+						'adminid' => 1, /* first admin-user (superadmin) */
+						'mod_fcgid_starter' => -1,
+						'mod_fcgid_maxrequests' => -1,
+						'guid' => $this->settings['phpfpm']['vhost_httpuser'],
+						'openbasedir' => 0,
+						'safemode' => '0',
+						'email' => $this->settings['panel']['adminmail'],
+						'loginname' => 'froxlor.panel',
+						'documentroot' => $mypath
+					);
+
+					$php = new phpinterface($this->getDB(), $this->settings, $domain);
+					$this->virtualhosts_data[$vhosts_filename].= '  SuexecUserGroup "' . $this->settings['system']['mod_fcgid_httpuser'] . '" "' . $this->settings['system']['mod_fcgid_httpgroup'] . '"' . "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '  FastCgiExternalServer ' . $mypath . 'fpm.external -socket ' . $php->getInterface()->getSocketFile() . ' -user ' . $this->settings['system']['mod_fcgid_httpuser'] . ' -group ' . $this->settings['system']['mod_fcgid_httpuser'] . "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '  <Directory "' . $mypath . '">' . "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '    AddHandler php5-fastcgi .php'. "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '    Action php5-fastcgi /fastcgiphp' . "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '    Options +ExecCGI' . "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '    Order allow,deny' . "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '    allow from all' . "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '  </Directory>' . "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '  Alias /fastcgiphp ' . $mypath . 'fpm.external' . "\n";
+				}
 
 				/**
 				 * dirprotection, see #72
@@ -1089,6 +1125,11 @@ class apache
 				$this->wipeOutOldDiroptionConfigs();
 			}
 		}
+		else
+		{
+			// no more diroptions, but there might be some file-corpses which have to be removed
+			$this->wipeOutOldDiroptionConfigs();
+		}
 
 		// Write htpasswds
 
@@ -1124,6 +1165,11 @@ class apache
 				$this->logger->logAction(CRON_ACTION, LOG_WARNING, 'WARNING!!! ' . $this->settings['system']['apacheconf_htpasswddir'] . ' is not a directory. htpasswd directory protection is disabled!!!');
 			}
 		}
+		else
+		{
+			// no more htpasswds, but there might be some file-corpses which have to be removed
+			$this->wipeOutOldHtpasswdConfigs();
+		}
 
 		// Write virtualhosts
 
