@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 1508 2010-11-29 07:44:24Z d00p $
+ * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 1538 2010-12-06 07:38:55Z d00p $
  */
 
 /*
@@ -61,6 +61,12 @@ class lighttpd
 
 	public function reload()
 	{
+		if((int)$this->settings['phpfpm']['enabled'] == 1)
+		{
+			fwrite($this->debugHandler, '   lighttpd::reload: reloading php-fpm' . "\n");
+			$this->logger->logAction(CRON_ACTION, LOG_INFO, 'reloading php-fpm');
+			safe_exec(escapeshellcmd($this->settings['phpfpm']['reload']));
+		}
 		fwrite($this->debugHandler, '   lighttpd::reload: reloading lighttpd' . "\n");
 		$this->logger->logAction(CRON_ACTION, LOG_INFO, 'reloading lighttpd');
 		safe_exec(escapeshellcmd($this->settings['system']['apachereload_command']));
@@ -138,6 +144,38 @@ class lighttpd
 				$this->lighttpd_data[$vhost_filename].= '  }' . "\n";
 				*/
 
+				/**
+				 * own php-fpm vhost
+				 */
+				if((int)$this->settings['phpfpm']['enabled'] == 1)
+				{
+					$domain = array(
+						'id' => 'none',
+						'domain' => $this->settings['system']['hostname'],
+						'adminid' => 1, /* first admin-user (superadmin) */
+						'mod_fcgid_starter' => -1,
+						'mod_fcgid_maxrequests' => -1,
+						'guid' => $this->settings['phpfpm']['vhost_httpuser'],
+						'openbasedir' => 0,
+						'safemode' => '0',
+						'email' => $this->settings['panel']['adminmail'],
+						'loginname' => 'froxlor.panel',
+						'documentroot' => $mypath
+					);
+	
+					$php = new phpinterface($this->getDB(), $this->settings, $domain);
+
+					$this->lighttpd_data[$vhost_filename].= '  fastcgi.server = ( '."\n";
+					$this->lighttpd_data[$vhost_filename].=	"\t".'".php" => ('."\n";
+					$this->lighttpd_data[$vhost_filename].=	"\t\t".'"localhost" => ('."\n";
+					$this->lighttpd_data[$vhost_filename].=	"\t\t".'"socket" => "'.$php->getInterface()->getSocketFile().'",'."\n";
+					$this->lighttpd_data[$vhost_filename].=	"\t\t".'"check-local" => "enable",'."\n";
+					$this->lighttpd_data[$vhost_filename].=	"\t\t".'"disable-time" => 1'."\n";
+					$this->lighttpd_data[$vhost_filename].=	"\t".')'."\n";
+					$this->lighttpd_data[$vhost_filename].=	"\t".')'."\n";
+					$this->lighttpd_data[$vhost_filename].=	'  )'."\n";
+				}
+
 				if($row_ipsandports['specialsettings'] != '')
 				{
 					$this->lighttpd_data[$vhost_filename].= $row_ipsandports['specialsettings'] . "\n";
