@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: cron_tasks.inc.http.30.nginx.php 1508 2010-11-29 07:44:24Z d00p $
+ * @version    $Id: cron_tasks.inc.http.30.nginx.php 1546 2010-12-09 11:49:07Z d00p $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -64,12 +64,19 @@ class nginx
 		/**
 		 * nginx does not auto-spawn fcgi-processes
 		 */
-		if  ($this->settings['system']['phpreload_command'] != '')
-		{
-			fwrite($this->debugHandler, '   nginx::reload: restarting php processes' . "\n");
+		if ($this->settings['system']['phpreload_command'] != ''
+			&& (int)$this->settings['phpfpm']['enabled'] == 0
+		) {
+		 	fwrite($this->debugHandler, '   nginx::reload: restarting php processes' . "\n");
 			$this->logger->logAction(CRON_ACTION, LOG_INFO, 'restarting php processes');
 			safe_exec($this->settings['system']['phpreload_command']);
 		}
+		elseif((int)$this->settings['phpfpm']['enabled'] == 1)
+		{
+			fwrite($this->debugHandler, '   nginx::reload: reloading php-fpm' . "\n");
+			$this->logger->logAction(CRON_ACTION, LOG_INFO, 'reloading php-fpm');
+			safe_exec(escapeshellcmd($this->settings['phpfpm']['reload']));
+		}
 	}
 
 	public function createVirtualHosts()
@@ -103,7 +110,7 @@ class nginx
 
 			if(!isset($this->nginx_data[$vhosts_filename]))
 			{
-				$this->vnginx_data[$vhosts_filename] = '';
+				$this->nginx_data[$vhosts_filename] = '';
 			}
 	
 			if($this->settings['defaultwebsrverrhandler']['err401'] != '')
@@ -221,8 +228,30 @@ class nginx
 			$this->nginx_data[$vhost_filename].= "\t".'location ~ \.php$ {'."\n";
 			$this->nginx_data[$vhost_filename].= "\t\t".'fastcgi_index index.php;'."\n";
 			$this->nginx_data[$vhost_filename].= "\t\t".'include /etc/nginx/fastcgi_params;'."\n";
-			$this->nginx_data[$vhost_filename].= "\t\t".'fastcgi_param SCRIPT_FILENAME $document_root' . '$fastcgi_script_name;'."\n";
-			$this->nginx_data[$vhost_filename].= "\t\t".'fastcgi_pass ' . $this->settings['system']['nginx_php_backend'] . ';' . "\n";
+			$this->nginx_data[$vhost_filename].= "\t\t".'fastcgi_param SCRIPT_FILENAME $document_root$fastcgi_script_name;'."\n";
+			if((int)$this->settings['phpfpm']['enabled'] == 1)
+			{
+				$domain = array(
+					'id' => 'none',
+					'domain' => $this->settings['system']['hostname'],
+					'adminid' => 1, /* first admin-user (superadmin) */
+					'mod_fcgid_starter' => -1,
+					'mod_fcgid_maxrequests' => -1,
+					'guid' => $this->settings['phpfpm']['vhost_httpuser'],
+					'openbasedir' => 0,
+					'safemode' => '0',
+					'email' => $this->settings['panel']['adminmail'],
+					'loginname' => 'froxlor.panel',
+					'documentroot' => $mypath
+				);
+
+				$php = new phpinterface($this->getDB(), $this->settings, $domain);
+				$this->nginx_data[$vhost_filename].= "\t\t".'fastcgi_pass unix:' . $php->getInterface()->getSocketFile() . ';' . "\n";
+			}
+			else
+			{
+				$this->nginx_data[$vhost_filename].= "\t\t".'fastcgi_pass ' . $this->settings['system']['nginx_php_backend'] . ';' . "\n";
+			}
 			$this->nginx_data[$vhost_filename].= "\t".'}'."\n";
 
 			$this->nginx_data[$vhost_filename].= '}' . "\n\n";
@@ -495,7 +524,7 @@ class nginx
 		$query = "SELECT * FROM " . TABLE_PANEL_HTPASSWDS . " WHERE `customerid`='" . $domain['customerid'] . "'";
 		$result = $this->db->query($query);
 
-		$result = array();
+		$returnval = array();
 		$x = 0;
 		while($row_htpasswds = $this->db->fetch_array($result))
 		{
@@ -515,13 +544,13 @@ class nginx
 
 				$path = makeCorrectDir(substr($row['path'], strlen($domain['documentroot']) - 1));
 
-				$result[$x]['path'] = $path;
-				$result[$x]['root'] = makeCorrectDir($domain['documentroot']);
-				$result[$x]['usrf'] = $htpasswd_filename;
+				$returnval[$x]['path'] = $path;
+				$returnval[$x]['root'] = makeCorrectDir($domain['documentroot']);
+				$returnval[$x]['usrf'] = $htpasswd_filename;
 				$x++;
 			}
 		}
-		return $result;
+		return $returnval;
 	}
 
 	protected function composePhpOptions($domain)
@@ -532,7 +561,7 @@ class nginx
 			$phpopts = "\t".'location ~ \.php$ {'."\n";
 			$phpopts.= "\t\t".'fastcgi_index index.php;'."\n";
 			$phpopts.= "\t\t".'include /etc/nginx/fastcgi_params;'."\n";
-			$phpopts.= "\t\t".'fastcgi_param SCRIPT_FILENAME $document_root' . '$fastcgi_script_name;'."\n";
+			$phpopts.= "\t\t".'fastcgi_param SCRIPT_FILENAME $document_root$fastcgi_script_name;'."\n";
 			$phpopts.= "\t\t".'fastcgi_pass ' . $this->settings['system']['nginx_php_backend'] . ';' . "\n";
 			$phpopts.= "\t".'}'."\n";
 		}
